<head>
  <meta charset="utf-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="theme-color" content="{{ site.primary-color }}"><!-- primary color -->

  <title>{% if page.title %}{{ page.title }}{% else %}{{ site.title }}{% endif %}</title>

  <link rel="canonical" href="{{ page.url | replace:'index.html','' | prepend: site.baseurl | prepend: site.url }}" />
  <link rel="alternate" type="application/rss+xml" title="{{ site.title }}" href="{{ "/feed.xml" | prepend: site.baseurl | prepend: site.url }}" />

  <link rel="stylesheet" href="{{ "/style.css" | prepend: site.baseurl }}" />
  
  <link rel="icon" type="image/png" href="{{ "/favicon.png" | prepend: site.baseurl }}" />
  <link rel="icon" sizes="144x144" href="{{ "/apple-touch-icon.png" | prepend: site.baseurl }}" />
  
  <!-- Twitter -->
  <meta property="twitter:title" content="{{site.title}}" />
  <meta property="twitter:image" content="{{ "/assets/card.web" | prepend: site.baseurl | prepend: site.url }}" />
  <meta property="twitter:card" content="summary_large_image" />
  <meta property="twitter:description" content="{{site.description}}" />

  <!-- Open Graph -->
  <meta property="og:title" content="{{ site.title }}" />
  <meta property="og:url" content="{{ site.url }}" />
  <meta property="og:description" content="{{ site.description }}" />
  <meta property="og:image" content="{{ "/assets/card.webp" | prepend: site.baseurl | prepend: site.url }}" />
</head>
